@@ -2,7 +2,12 @@ import sys
 import subprocess
 from uvicorn.main import main
 
-if __name__ == "__main__":
-    args = "idservice:app --no-access-log --loop uvloop".split(" ")
+
+def start():
+    args = "idservice.api:app --no-access-log --loop uvloop".split(" ")
     sys.argv.extend(args)
     main()
+
+
+if __name__ == "__main__":
+    start()
